@@ -25,7 +25,7 @@ def getHeaders():
 def format_datetime(dt):
     try:
         ret = ''
-        pattern = re.compile('\\d+[-年/]+\\d+[-月/]+\\d+[日]?\s?\\d*[:]?\\d*[:]?\\d{1,2}')
+        pattern = re.compile('\\d+[-年/]+\\d+[-月/]+\\d+[日]?\s?\\d*[:]?\\d*[:]?\\d{0,2}')
         pattern1 = re.compile('\\d{1,2}[-月]+\\d{1,2}[日]?')
         pattern2 = re.compile('\\d{1,2}:\\d{1,2}')
         pattern3 = re.compile('\\d{1,2}[-月/]+\\d{1,2}[日]?[\\s]*\\d{1,2}:\\d{1,2}')
@@ -118,8 +118,3 @@ def format_string(text):
     pattern = re.compile('<[A-Za-z\\/].*?>')
     text = re.sub(pattern, '', text)
     return text
-
-
-def format_phone(phone):
-    phone = re.sub(u"([^0-9+])", "", phone)
-    return phone
